@@ -4,16 +4,16 @@
  * For LGPL see License.txt in the project root for license information.
  * For commercial licenses see https://www.tiny.cloud/
  *
- * Version: 5.8.2 (2021-06-23)
+ * Version: 5.10.9 (2023-11-15)
  */
 (function () {
     'use strict';
 
-    var global = tinymce.util.Tools.resolve('tinymce.PluginManager');
+    var global$2 = tinymce.util.Tools.resolve('tinymce.PluginManager');
 
     var global$1 = tinymce.util.Tools.resolve('tinymce.dom.DOMUtils');
 
-    var global$2 = tinymce.util.Tools.resolve('tinymce.util.Tools');
+    var global = tinymce.util.Tools.resolve('tinymce.util.Tools');
 
     var enableWhenDirty = function (editor) {
       return editor.getParam('save_enablewhendirty', true);
@@ -57,7 +57,7 @@
       }
     };
     var cancel = function (editor) {
-      var h = global$2.trim(editor.startContent);
+      var h = global.trim(editor.startContent);
       if (hasOnCancelCallback(editor)) {
         editor.execCallback('save_oncancelcallback', editor);
         return;
@@ -65,7 +65,7 @@
       editor.resetContent(h);
     };
 
-    var register = function (editor) {
+    var register$1 = function (editor) {
       editor.addCommand('mceSave', function () {
         save(editor);
       });
@@ -79,13 +79,14 @@
         var handler = function () {
           api.setDisabled(enableWhenDirty(editor) && !editor.isDirty());
         };
+        handler();
         editor.on('NodeChange dirty', handler);
         return function () {
           return editor.off('NodeChange dirty', handler);
         };
       };
     };
-    var register$1 = function (editor) {
+    var register = function (editor) {
       editor.ui.registry.addButton('save', {
         icon: 'save',
         tooltip: 'Save',
@@ -108,9 +109,9 @@
     };
 
     function Plugin () {
-      global.add('save', function (editor) {
-        register$1(editor);
+      global$2.add('save', function (editor) {
         register(editor);
+        register$1(editor);
       });
     }
 
