@@ -1,7 +1,7 @@
 import { Fun } from '@ephox/katamari';
 import { Compare, PredicateExists, SugarElement } from '@ephox/sugar';
-import { AlloyComponent } from '../api/component/ComponentApi';
 
+import { AlloyComponent } from '../api/component/ComponentApi';
 import * as AriaOwner from '../aria/AriaOwner';
 import { AnchorSpec } from '../positioning/mode/Anchoring';
 
@@ -12,7 +12,7 @@ const isPartOf = (component: AlloyComponent, queryElem: SugarElement): boolean =
   PredicateExists.closest(queryElem, (el: SugarElement) => Compare.eq(el, component.element), Fun.never) || isAriaPartOf(component, queryElem);
 
 const isPartOfAnchor = (anchor: AnchorSpec, queryElem: SugarElement): boolean =>
-  anchor.anchor === 'hotspot' && isPartOf(anchor.hotspot, queryElem);
+  anchor.type === 'hotspot' && isPartOf(anchor.hotspot, queryElem);
 
 export {
   isPartOf,
