@@ -1,7 +1,7 @@
 import { FieldSchema } from '@ephox/boulder';
 
 export default [
-  FieldSchema.strict('channel'),
+  FieldSchema.required('channel'),
   FieldSchema.option('renderComponents'),
   FieldSchema.option('updateState'),
   FieldSchema.option('initialData')
