@@ -3,18 +3,16 @@ import { Cell, Optional } from '@ephox/katamari';
 import { ReflectingState } from './ReflectingTypes';
 
 const init = <S>(): ReflectingState<S> => {
-  const cell: Cell<Optional<S>> = Cell(Optional.none<S>());
+  const cell = Cell(Optional.none<S>());
 
-  const set = (optS: Optional<S>) => cell.set(optS);
   const clear = () => cell.set(Optional.none<S>());
-  const get = () => cell.get();
 
-  const readState = (): any => cell.get().fold<any>(() => 'none', (x) => x);
+  const readState = (): any => cell.get().getOr('none');
 
   return {
     readState,
-    get,
-    set,
+    get: cell.get,
+    set: cell.set,
     clear
   };
 };
