@@ -1,4 +1,4 @@
-import { FieldProcessorAdt, FieldSchema } from '@ephox/boulder';
+import { FieldSchema } from '@ephox/boulder';
 import { Fun } from '@ephox/katamari';
 
 import { Keying } from '../../api/behaviour/Keying';
@@ -7,8 +7,8 @@ import * as Fields from '../../data/Fields';
 import * as PartType from '../../parts/PartType';
 import { ToolbarGroupDetail, ToolbarGroupSpec } from '../types/ToolbarGroupTypes';
 
-const schema: () => FieldProcessorAdt[] = Fun.constant([
-  FieldSchema.strict('items'),
+const schema = Fun.constant([
+  FieldSchema.required('items'),
   Fields.markers([ 'itemSelector' ]),
   SketchBehaviours.field('tgroupBehaviours', [ Keying ])
 ]);
