@@ -1,6 +1,9 @@
-import { Arr, Fun, Optional } from '@ephox/katamari';
-import { Remove, SugarElement, SugarNode, Width } from '@ephox/sugar';
+import { Arr, Fun, Optional, Optionals } from '@ephox/katamari';
+import { ContentEditable, Remove, SugarElement, Width } from '@ephox/sugar';
+
+import { TableSection } from '../api/TableSection';
 import * as Blocks from '../lookup/Blocks';
+import { findCommonCellType, findCommonRowType } from '../lookup/Type';
 import * as DetailsList from '../model/DetailsList';
 import * as GridRow from '../model/GridRow';
 import * as RunOperation from '../model/RunOperation';
@@ -39,7 +42,12 @@ interface ExtractColsDetail {
 
 type CompElm = (e1: SugarElement, e2: SugarElement) => boolean;
 
-const prune = (table: SugarElement) => {
+// This uses a slight variation to the default `ContentEditable.isEditable` behaviour,
+// as when the element is detached we assume it is editable because it is a new cell.
+const isEditable = (elem: SugarElement<HTMLElement>) =>
+  ContentEditable.isEditable(elem, true);
+
+const prune = (table: SugarElement<HTMLTableElement>) => {
   const cells = TableLookup.cells(table);
   if (cells.length === 0) {
     Remove.remove(table);
@@ -51,23 +59,25 @@ const outcome = (grid: Structs.RowCells[], cursor: Optional<SugarElement>): Tabl
   cursor
 });
 
+const findEditableCursorPosition = (rows: Structs.RowCells[]) =>
+  Arr.findMap(rows, (row) =>
+    Arr.findMap(row.cells, (cell) => {
+      const elem = cell.element;
+      return Optionals.someIf(isEditable(elem), elem);
+    })
+  );
+
 const elementFromGrid = (grid: Structs.RowCells[], row: number, column: number) => {
   const rows = GridRow.extractGridDetails(grid).rows;
-  return findIn(rows, row, column).orThunk(() =>
-    findIn(rows, 0, 0)
-  );
+  return Optional.from(rows[row]?.cells[column]?.element)
+    .filter(isEditable)
+    // Fallback to the first valid position in the table
+    .orThunk(() => findEditableCursorPosition(rows));
 };
 
-const findIn = (grid: Structs.RowCells[], row: number, column: number) =>
-  Optional.from(grid[row]).bind((r) =>
-    Optional.from(r.cells[column]).bind((c) =>
-      Optional.from(c.element)
-    )
-  );
-
 const bundle = (grid: Structs.RowCells[], row: number, column: number) => {
-  const rows = GridRow.extractGridDetails(grid).rows;
-  return outcome(grid, findIn(rows, row, column));
+  const cursorElement = elementFromGrid(grid, row, column);
+  return outcome(grid, cursorElement);
 };
 
 const uniqueRows = (details: Structs.DetailExt[]) => {
@@ -154,68 +164,71 @@ const opInsertColumnsAfter = (grid: Structs.RowCells[], extractDetail: ExtractCo
   return bundle(newGrid, details[0].row, targetIndex);
 };
 
-const opMakeRowHeader = (grid: Structs.RowCells[], detail: Structs.DetailExt, comparator: CompElm, genWrappers: GeneratorsTransform) => {
-  const newGrid = TransformOperations.replaceRow(grid, detail.row, comparator, genWrappers.replaceOrInit);
-  return bundle(newGrid, detail.row, detail.column);
-};
-
-const opMakeRowsHeader = (initialGrid: Structs.RowCells[], details: Structs.DetailExt[], comparator: CompElm, genWrappers: GeneratorsTransform) => {
-  const rows = uniqueRows(details);
-
-  const replacer = (currentGrid: Structs.RowCells[], row: Structs.DetailExt) => TransformOperations.replaceRow(currentGrid, row.row, comparator, genWrappers.replaceOrInit);
-
-  const newGrid = Arr.foldl(rows, replacer, initialGrid);
-
-  return bundle(newGrid, details[0].row, details[0].column);
-};
-
 const opMakeColumnHeader = (initialGrid: Structs.RowCells[], detail: Structs.DetailExt, comparator: CompElm, genWrappers: GeneratorsTransform) => {
-  const newGrid = TransformOperations.replaceColumn(initialGrid, detail.column, comparator, genWrappers.replaceOrInit);
-
+  const newGrid = TransformOperations.replaceColumn(initialGrid, detail.column, true, comparator, genWrappers.replaceOrInit);
   return bundle(newGrid, detail.row, detail.column);
 };
 
 const opMakeColumnsHeader = (initialGrid: Structs.RowCells[], details: Structs.DetailExt[], comparator: CompElm, genWrappers: GeneratorsTransform) => {
   const columns = ColUtils.uniqueColumns(details);
-
-  const replacer = (currentGrid: Structs.RowCells[], column: Structs.DetailExt) => TransformOperations.replaceColumn(currentGrid, column.column, comparator, genWrappers.replaceOrInit);
-
-  const newGrid = Arr.foldl(columns, replacer, initialGrid);
-
+  const columnIndexes = Arr.map(columns, (detail) => detail.column);
+  const newGrid = TransformOperations.replaceColumns(initialGrid, columnIndexes, true, comparator, genWrappers.replaceOrInit);
   return bundle(newGrid, details[0].row, details[0].column);
 };
 
-const opUnmakeRowHeader = (grid: Structs.RowCells[], detail: Structs.DetailExt, comparator: CompElm, genWrappers: GeneratorsTransform) => {
-  const newGrid = TransformOperations.replaceRow(grid, detail.row, comparator, genWrappers.replaceOrInit);
+const opMakeCellHeader = (initialGrid: Structs.RowCells[], detail: Structs.DetailExt, comparator: CompElm, genWrappers: GeneratorsTransform) => {
+  const newGrid = TransformOperations.replaceCell(initialGrid, detail, comparator, genWrappers.replaceOrInit);
   return bundle(newGrid, detail.row, detail.column);
 };
 
-const opUnmakeRowsHeader = (initialGrid: Structs.RowCells[], details: Structs.DetailExt[], comparator: CompElm, genWrappers: GeneratorsTransform) => {
-  const rows = uniqueRows(details);
-
-  const replacer = (currentGrid: Structs.RowCells[], row: Structs.DetailExt) => TransformOperations.replaceRow(currentGrid, row.row, comparator, genWrappers.replaceOrInit);
-
-  const newGrid = Arr.foldl(rows, replacer, initialGrid);
-
+const opMakeCellsHeader = (initialGrid: Structs.RowCells[], details: Structs.DetailExt[], comparator: CompElm, genWrappers: GeneratorsTransform) => {
+  const newGrid = TransformOperations.replaceCells(initialGrid, details, comparator, genWrappers.replaceOrInit);
   return bundle(newGrid, details[0].row, details[0].column);
 };
 
 const opUnmakeColumnHeader = (initialGrid: Structs.RowCells[], detail: Structs.DetailExt, comparator: CompElm, genWrappers: GeneratorsTransform) => {
-  const newGrid = TransformOperations.replaceColumn(initialGrid, detail.column, comparator, genWrappers.replaceOrInit);
-
+  const newGrid = TransformOperations.replaceColumn(initialGrid, detail.column, false, comparator, genWrappers.replaceOrInit);
   return bundle(newGrid, detail.row, detail.column);
 };
 
 const opUnmakeColumnsHeader = (initialGrid: Structs.RowCells[], details: Structs.DetailExt[], comparator: CompElm, genWrappers: GeneratorsTransform) => {
   const columns = ColUtils.uniqueColumns(details);
-
-  const replacer = (currentGrid: Structs.RowCells[], column: Structs.DetailExt) => TransformOperations.replaceColumn(currentGrid, column.column, comparator, genWrappers.replaceOrInit);
-
-  const newGrid = Arr.foldl(columns, replacer, initialGrid);
-
+  const columnIndexes = Arr.map(columns, (detail) => detail.column);
+  const newGrid = TransformOperations.replaceColumns(initialGrid, columnIndexes, false, comparator, genWrappers.replaceOrInit);
   return bundle(newGrid, details[0].row, details[0].column);
 };
 
+const opUnmakeCellHeader = (initialGrid: Structs.RowCells[], detail: Structs.DetailExt, comparator: CompElm, genWrappers: GeneratorsTransform) => {
+  const newGrid = TransformOperations.replaceCell(initialGrid, detail, comparator, genWrappers.replaceOrInit);
+  return bundle(newGrid, detail.row, detail.column);
+};
+
+const opUnmakeCellsHeader = (initialGrid: Structs.RowCells[], details: Structs.DetailExt[], comparator: CompElm, genWrappers: GeneratorsTransform) => {
+  const newGrid = TransformOperations.replaceCells(initialGrid, details, comparator, genWrappers.replaceOrInit);
+  return bundle(newGrid, details[0].row, details[0].column);
+};
+
+const makeRowSection = (section: Structs.Section, applyScope: boolean) =>
+  (grid: Structs.RowCells[], detail: Structs.DetailExt, comparator: CompElm, genWrappers: GeneratorsTransform, tableSection: TableSection) => {
+    const newGrid = TransformOperations.replaceRow(grid, detail.row, section, applyScope, comparator, genWrappers.replaceOrInit, tableSection);
+    return bundle(newGrid, detail.row, detail.column);
+  };
+
+const makeRowsSection = (section: Structs.Section, applyScope: boolean) =>
+  (initialGrid: Structs.RowCells[], details: Structs.DetailExt[], comparator: CompElm, genWrappers: GeneratorsTransform, tableSection: TableSection) => {
+    const rows = uniqueRows(details);
+    const rowIndexes = Arr.map(rows, (detail) => detail.row);
+    const newGrid = TransformOperations.replaceRows(initialGrid, rowIndexes, section, applyScope, comparator, genWrappers.replaceOrInit, tableSection);
+    return bundle(newGrid, details[0].row, details[0].column);
+  };
+
+const opMakeRowHeader = makeRowSection('thead', true);
+const opMakeRowsHeader = makeRowsSection('thead', true);
+const opMakeRowBody = makeRowSection('tbody', false);
+const opMakeRowsBody = makeRowsSection('tbody', false);
+const opMakeRowFooter = makeRowSection('tfoot', false);
+const opMakeRowsFooter = makeRowsSection('tfoot', false);
+
 const opSplitCellIntoColumns = (grid: Structs.RowCells[], detail: Structs.DetailExt, comparator: CompElm, genWrappers: GeneratorsModification) => {
   const newGrid = ModificationOperations.splitCellIntoColumns(grid, detail.row, detail.column, comparator, genWrappers.getOrInit);
   return bundle(newGrid, detail.row, detail.column);
@@ -230,16 +243,16 @@ const opEraseColumns = (grid: Structs.RowCells[], extractDetail: ExtractColsDeta
   const columns = ColUtils.uniqueColumns(extractDetail.details);
 
   const newGrid = ModificationOperations.deleteColumnsAt(grid, Arr.map(columns, (column) => column.column));
-  const cursor = elementFromGrid(newGrid, columns[0].row, columns[0].column);
-  return outcome(newGrid, cursor);
+  const maxColIndex = newGrid.length > 0 ? newGrid[0].cells.length - 1 : 0;
+  return bundle(newGrid, columns[0].row, Math.min(columns[0].column, maxColIndex));
 };
 
 const opEraseRows = (grid: Structs.RowCells[], details: Structs.DetailExt[], _comparator: CompElm, _genWrappers: GeneratorsModification) => {
   const rows = uniqueRows(details);
 
   const newGrid = ModificationOperations.deleteRowsAt(grid, rows[0].row, rows[rows.length - 1].row);
-  const cursor = elementFromGrid(newGrid, details[0].row, details[0].column);
-  return outcome(newGrid, cursor);
+  const maxRowIndex = newGrid.length > 0 ? newGrid.length - 1 : 0;
+  return bundle(newGrid, Math.min(details[0].row, maxRowIndex), details[0].column);
 };
 
 const opMergeCells = (grid: Structs.RowCells[], mergable: ExtractMergable, comparator: CompElm, genWrappers: GeneratorsMerging) => {
@@ -271,8 +284,7 @@ const opPasteCells = (grid: Structs.RowCells[], pasteDetails: ExtractPaste, comp
   return mergedGrid.fold(
     () => outcome(grid, Optional.some(pasteDetails.element)),
     (newGrid) => {
-      const cursor = elementFromGrid(newGrid, pasteDetails.row, pasteDetails.column);
-      return outcome(newGrid, cursor);
+      return bundle(newGrid, pasteDetails.row, pasteDetails.column);
     }
   );
 };
@@ -289,8 +301,7 @@ const opPasteColsBefore = (grid: Structs.RowCells[], pasteDetails: ExtractPasteR
   const context = rows[pasteDetails.cells[0].row];
   const gridB = gridifyRows(pasteDetails.clipboard, pasteDetails.generators, context);
   const mergedGrid = TableMerge.insertCols(index, grid, gridB, pasteDetails.generators, comparator);
-  const cursor = elementFromGrid(mergedGrid, pasteDetails.cells[0].row, pasteDetails.cells[0].column);
-  return outcome(mergedGrid, cursor);
+  return bundle(mergedGrid, pasteDetails.cells[0].row, pasteDetails.cells[0].column);
 };
 
 const opPasteColsAfter = (grid: Structs.RowCells[], pasteDetails: ExtractPasteRows, comparator: CompElm, _genWrappers: GeneratorsModification) => {
@@ -299,8 +310,7 @@ const opPasteColsAfter = (grid: Structs.RowCells[], pasteDetails: ExtractPasteRo
   const context = rows[pasteDetails.cells[0].row];
   const gridB = gridifyRows(pasteDetails.clipboard, pasteDetails.generators, context);
   const mergedGrid = TableMerge.insertCols(index, grid, gridB, pasteDetails.generators, comparator);
-  const cursor = elementFromGrid(mergedGrid, pasteDetails.cells[0].row, pasteDetails.cells[0].column);
-  return outcome(mergedGrid, cursor);
+  return bundle(mergedGrid, pasteDetails.cells[0].row, pasteDetails.cells[0].column);
 };
 
 const opPasteRowsBefore = (grid: Structs.RowCells[], pasteDetails: ExtractPasteRows, comparator: CompElm, _genWrappers: GeneratorsModification) => {
@@ -309,8 +319,7 @@ const opPasteRowsBefore = (grid: Structs.RowCells[], pasteDetails: ExtractPasteR
   const context = rows[index];
   const gridB = gridifyRows(pasteDetails.clipboard, pasteDetails.generators, context);
   const mergedGrid = TableMerge.insertRows(index, grid, gridB, pasteDetails.generators, comparator);
-  const cursor = elementFromGrid(mergedGrid, pasteDetails.cells[0].row, pasteDetails.cells[0].column);
-  return outcome(mergedGrid, cursor);
+  return bundle(mergedGrid, pasteDetails.cells[0].row, pasteDetails.cells[0].column);
 };
 
 const opPasteRowsAfter = (grid: Structs.RowCells[], pasteDetails: ExtractPasteRows, comparator: CompElm, _genWrappers: GeneratorsModification) => {
@@ -319,37 +328,46 @@ const opPasteRowsAfter = (grid: Structs.RowCells[], pasteDetails: ExtractPasteRo
   const context = rows[pasteDetails.cells[0].row];
   const gridB = gridifyRows(pasteDetails.clipboard, pasteDetails.generators, context);
   const mergedGrid = TableMerge.insertRows(index, grid, gridB, pasteDetails.generators, comparator);
-  const cursor = elementFromGrid(mergedGrid, pasteDetails.cells[0].row, pasteDetails.cells[0].column);
-  return outcome(mergedGrid, cursor);
+  return bundle(mergedGrid, pasteDetails.cells[0].row, pasteDetails.cells[0].column);
 };
 
-const opGetColumnType = (table: SugarElement, target: TargetSelection): string => {
+const opGetColumnsType = (table: SugarElement<HTMLTableElement>, target: TargetSelection): string => {
   const house = Warehouse.fromTable(table);
   const details = RunOperation.onCells(house, target);
-  return details.bind((selectedCells): Optional<string> => {
+  return details.bind((selectedCells) => {
     const lastSelectedCell = selectedCells[selectedCells.length - 1];
     const minColRange = selectedCells[0].column;
     const maxColRange = lastSelectedCell.column + lastSelectedCell.colspan;
     const selectedColumnCells = Arr.flatten(Arr.map(house.all, (row) =>
       Arr.filter(row.cells, (cell) => cell.column >= minColRange && cell.column < maxColRange)));
-    return getCellsType(selectedColumnCells, (cell) => SugarNode.name(cell.element) === 'th');
+    return findCommonCellType(selectedColumnCells);
   }).getOr('');
 };
 
-export const getCellsType = <T>(cells: T[], headerPred: (x: T) => boolean): Optional<string> => {
-  const headerCells = Arr.filter(cells, headerPred);
-  if (headerCells.length === 0) {
-    return Optional.some('td');
-  } else if (headerCells.length === cells.length) {
-    return Optional.some('th');
-  } else {
-    return Optional.none();
-  }
+const opGetCellsType = (table: SugarElement<HTMLTableElement>, target: TargetSelection): string => {
+  const house = Warehouse.fromTable(table);
+  const details = RunOperation.onCells(house, target);
+  return details.bind(findCommonCellType).getOr('');
+};
+
+const opGetRowsType = (table: SugarElement<HTMLTableElement>, target: TargetSelection): string => {
+  const house = Warehouse.fromTable(table);
+  const details = RunOperation.onCells(house, target);
+  return details.bind((selectedCells) => {
+    const lastSelectedCell = selectedCells[selectedCells.length - 1];
+    const minRowRange = selectedCells[0].row;
+    const maxRowRange = lastSelectedCell.row + lastSelectedCell.rowspan;
+    const selectedRows = house.all.slice(minRowRange, maxRowRange);
+    return findCommonRowType(selectedRows);
+  }).getOr('');
 };
 
 // Only column modifications force a resizing. Everything else just tries to preserve the table as is.
-const resize = Adjustments.adjustWidthTo;
-const adjustAndRedistributeWidths = Adjustments.adjustAndRedistributeWidths;
+const resize: RunOperation.Adjustment<{}> = (table, list, details, behaviours) =>
+  Adjustments.adjustWidthTo(table, list, details, behaviours.sizing);
+
+const adjustAndRedistributeWidths: RunOperation.Adjustment<{ pixelDelta: number }> = (table, list, details, behaviours) =>
+  Adjustments.adjustAndRedistributeWidths(table, list, details, behaviours.sizing, behaviours.resize);
 
 // Custom selection extractors
 
@@ -399,6 +417,9 @@ const pasteColumnsExtractor = (before: boolean) => (warehouse: Warehouse, target
     return !checkLocked(warehouse, details.cells);
   });
 
+const headerCellGenerator = Generators.transform('th');
+const bodyCellGenerator = Generators.transform('td');
+
 export const insertRowBefore = RunOperation.run(opInsertRowBefore, RunOperation.onCell, Fun.noop, Fun.noop, Generators.modification);
 export const insertRowsBefore = RunOperation.run(opInsertRowsBefore, RunOperation.onCells, Fun.noop, Fun.noop, Generators.modification);
 export const insertRowAfter = RunOperation.run(opInsertRowAfter, RunOperation.onCell, Fun.noop, Fun.noop, Generators.modification);
@@ -411,14 +432,20 @@ export const splitCellIntoColumns = RunOperation.run(opSplitCellIntoColumns, Run
 export const splitCellIntoRows = RunOperation.run(opSplitCellIntoRows, RunOperation.onUnlockedCell, Fun.noop, Fun.noop, Generators.modification);
 export const eraseColumns = RunOperation.run(opEraseColumns, eraseColumnsExtractor, adjustAndRedistributeWidths, prune, Generators.modification);
 export const eraseRows = RunOperation.run(opEraseRows, RunOperation.onCells, Fun.noop, prune, Generators.modification);
-export const makeColumnHeader = RunOperation.run(opMakeColumnHeader, RunOperation.onUnlockedCell, Fun.noop, Fun.noop, Generators.transform('row', 'th'));
-export const makeColumnsHeader = RunOperation.run(opMakeColumnsHeader, RunOperation.onUnlockedCells, Fun.noop, Fun.noop, Generators.transform('row', 'th'));
-export const unmakeColumnHeader = RunOperation.run(opUnmakeColumnHeader, RunOperation.onUnlockedCell, Fun.noop, Fun.noop, Generators.transform(null, 'td'));
-export const unmakeColumnsHeader = RunOperation.run(opUnmakeColumnsHeader, RunOperation.onUnlockedCells, Fun.noop, Fun.noop, Generators.transform(null, 'td'));
-export const makeRowHeader = RunOperation.run(opMakeRowHeader, RunOperation.onCell, Fun.noop, Fun.noop, Generators.transform('col', 'th'));
-export const makeRowsHeader = RunOperation.run(opMakeRowsHeader, RunOperation.onCells, Fun.noop, Fun.noop, Generators.transform('col', 'th'));
-export const unmakeRowHeader = RunOperation.run(opUnmakeRowHeader, RunOperation.onCell, Fun.noop, Fun.noop, Generators.transform(null, 'td'));
-export const unmakeRowsHeader = RunOperation.run(opUnmakeRowsHeader, RunOperation.onCells, Fun.noop, Fun.noop, Generators.transform(null, 'td'));
+export const makeColumnHeader = RunOperation.run(opMakeColumnHeader, RunOperation.onUnlockedCell, Fun.noop, Fun.noop, headerCellGenerator);
+export const makeColumnsHeader = RunOperation.run(opMakeColumnsHeader, RunOperation.onUnlockedCells, Fun.noop, Fun.noop, headerCellGenerator);
+export const unmakeColumnHeader = RunOperation.run(opUnmakeColumnHeader, RunOperation.onUnlockedCell, Fun.noop, Fun.noop, bodyCellGenerator);
+export const unmakeColumnsHeader = RunOperation.run(opUnmakeColumnsHeader, RunOperation.onUnlockedCells, Fun.noop, Fun.noop, bodyCellGenerator);
+export const makeRowHeader = RunOperation.run(opMakeRowHeader, RunOperation.onUnlockedCell, Fun.noop, Fun.noop, headerCellGenerator);
+export const makeRowsHeader = RunOperation.run(opMakeRowsHeader, RunOperation.onUnlockedCells, Fun.noop, Fun.noop, headerCellGenerator);
+export const makeRowBody = RunOperation.run(opMakeRowBody, RunOperation.onUnlockedCell, Fun.noop, Fun.noop, bodyCellGenerator);
+export const makeRowsBody = RunOperation.run(opMakeRowsBody, RunOperation.onUnlockedCells, Fun.noop, Fun.noop, bodyCellGenerator);
+export const makeRowFooter = RunOperation.run(opMakeRowFooter, RunOperation.onUnlockedCell, Fun.noop, Fun.noop, bodyCellGenerator);
+export const makeRowsFooter = RunOperation.run(opMakeRowsFooter, RunOperation.onUnlockedCells, Fun.noop, Fun.noop, bodyCellGenerator);
+export const makeCellHeader = RunOperation.run(opMakeCellHeader, RunOperation.onUnlockedCell, Fun.noop, Fun.noop, headerCellGenerator);
+export const makeCellsHeader = RunOperation.run(opMakeCellsHeader, RunOperation.onUnlockedCells, Fun.noop, Fun.noop, headerCellGenerator);
+export const unmakeCellHeader = RunOperation.run(opUnmakeCellHeader, RunOperation.onUnlockedCell, Fun.noop, Fun.noop, bodyCellGenerator);
+export const unmakeCellsHeader = RunOperation.run(opUnmakeCellsHeader, RunOperation.onUnlockedCells, Fun.noop, Fun.noop, bodyCellGenerator);
 export const mergeCells = RunOperation.run(opMergeCells, RunOperation.onUnlockedMergable, resize, Fun.noop, Generators.merging);
 export const unmergeCells = RunOperation.run(opUnmergeCells, RunOperation.onUnlockedUnmergable, resize, Fun.noop, Generators.merging);
 export const pasteCells = RunOperation.run(opPasteCells, RunOperation.onPaste, resize, Fun.noop, Generators.modification);
@@ -426,4 +453,7 @@ export const pasteColsBefore = RunOperation.run(opPasteColsBefore, pasteColumnsE
 export const pasteColsAfter = RunOperation.run(opPasteColsAfter, pasteColumnsExtractor(false), Fun.noop, Fun.noop, Generators.modification);
 export const pasteRowsBefore = RunOperation.run(opPasteRowsBefore, RunOperation.onPasteByEditor, Fun.noop, Fun.noop, Generators.modification);
 export const pasteRowsAfter = RunOperation.run(opPasteRowsAfter, RunOperation.onPasteByEditor, Fun.noop, Fun.noop, Generators.modification);
-export const getColumnType = opGetColumnType;
+
+export const getColumnsType = opGetColumnsType;
+export const getCellsType = opGetCellsType;
+export const getRowsType = opGetRowsType;
