@@ -1,4 +1,5 @@
 import { Dimension } from '../../impl/Dimension';
+import * as RuntimeSize from '../../impl/RuntimeSize';
 import * as SugarBody from '../node/SugarBody';
 import { SugarElement } from '../node/SugarElement';
 import * as Css from '../properties/Css';
@@ -15,6 +16,10 @@ const get = (element: SugarElement<HTMLElement>): number => api.get(element);
 
 const getOuter = (element: SugarElement<HTMLElement>): number => api.getOuter(element);
 
+const getInner = RuntimeSize.getInnerHeight;
+
+const getRuntime = RuntimeSize.getHeight;
+
 const setMax = (element: SugarElement<HTMLElement>, value: number): void => {
   // These properties affect the absolute max-height, they are not counted natively, we want to include these properties.
   const inclusions = [ 'margin-top', 'border-top-width', 'padding-top', 'padding-bottom', 'border-bottom-width', 'margin-bottom' ];
@@ -25,6 +30,8 @@ const setMax = (element: SugarElement<HTMLElement>, value: number): void => {
 export {
   set,
   get,
+  getInner,
   getOuter,
+  getRuntime,
   setMax
 };
