@@ -6,13 +6,14 @@
  */
 
 import PluginManager from 'tinymce/core/api/PluginManager';
+
 import * as Commands from './api/Commands';
 import * as FilterContent from './core/FilterContent';
 import * as Buttons from './ui/Buttons';
 import * as Dialog from './ui/Dialog';
 import * as Utils from './util/Utils';
 
-export default () => {
+export default (): void => {
   PluginManager.add('codesample', (editor) => {
     FilterContent.setup(editor);
     Buttons.register(editor);
