@@ -6,13 +6,15 @@
  */
 
 import { Cell } from '@ephox/katamari';
+
 import PluginManager from 'tinymce/core/api/PluginManager';
+
 import * as Api from './api/Api';
 import * as Commands from './api/Commands';
 import { ScrollInfo } from './core/Actions';
 import * as Buttons from './ui/Buttons';
 
-export default () => {
+export default (): void => {
   PluginManager.add('fullscreen', (editor) => {
     const fullscreenState = Cell<ScrollInfo | null>(null);
 
