@@ -6,10 +6,11 @@
  */
 
 import PluginManager from 'tinymce/core/api/PluginManager';
+
 import * as Api from './api/Api';
 import * as ImportCss from './core/ImportCss';
 
-export default () => {
+export default (): void => {
   PluginManager.add('importcss', (editor) => {
     ImportCss.setup(editor);
     return Api.get(editor);
