@@ -8,9 +8,9 @@
 import Editor from 'tinymce/core/api/Editor';
 
 export interface DomModifier {
-  setAttrib: (attr: string, value: string) => void;
-  setStyle: (prop: string, value: string) => void;
-  setFormat: (formatName: string, value: string) => void;
+  readonly setAttrib: (attr: string, value: string) => void;
+  readonly setStyle: (prop: string, value: string) => void;
+  readonly setFormat: (formatName: string, value: string) => void;
 }
 
 // The get node is required here because it can be transformed
