@@ -6,18 +6,19 @@
  */
 
 import { Cell } from '@ephox/katamari';
+
 import Editor from 'tinymce/core/api/Editor';
 import Delay from 'tinymce/core/api/util/Delay';
-import { EditorEvent } from 'tinymce/core/api/util/EventDispatcher';
 import VK from 'tinymce/core/api/util/VK';
+
 import { PatternSet } from '../core/PatternTypes';
 import * as KeyHandler from './KeyHandler';
 
-const setup = (editor: Editor, patternsState: Cell<PatternSet>) => {
+const setup = (editor: Editor, patternsState: Cell<PatternSet>): void => {
   const charCodes = [ ',', '.', ';', ':', '!', '?' ];
   const keyCodes = [ 32 ];
 
-  editor.on('keydown', (e: EditorEvent<KeyboardEvent>) => {
+  editor.on('keydown', (e) => {
     if (e.keyCode === 13 && !VK.modifierPressed(e)) {
       if (KeyHandler.handleEnter(editor, patternsState.get())) {
         e.preventDefault();
@@ -25,13 +26,13 @@ const setup = (editor: Editor, patternsState: Cell<PatternSet>) => {
     }
   }, true);
 
-  editor.on('keyup', (e: EditorEvent<KeyboardEvent>) => {
+  editor.on('keyup', (e) => {
     if (KeyHandler.checkKeyCode(keyCodes, e)) {
       KeyHandler.handleInlineKey(editor, patternsState.get());
     }
   });
 
-  editor.on('keypress', (e: EditorEvent<KeyboardEvent>) => {
+  editor.on('keypress', (e) => {
     if (KeyHandler.checkCharCode(charCodes, e)) {
       Delay.setEditorTimeout(editor, () => {
         KeyHandler.handleInlineKey(editor, patternsState.get());
