@@ -7,9 +7,8 @@
 
 import * as Data from './Data';
 
-const wrapCharWithSpan = (value) => {
-  return '<span data-mce-bogus="1" class="mce-' + Data.charMap[value] + '">' + value + '</span>';
-};
+const wrapCharWithSpan = (value: string): string =>
+  '<span data-mce-bogus="1" class="mce-' + Data.charMap[value] + '">' + value + '</span>';
 
 export {
   wrapCharWithSpan
